@@ -100,6 +100,7 @@ static GRand *rgen;
 static GtkWidget *draw_area;
 static GtkWidget *app, *headerbar, *pref_dialog, *gridframe;
 static GtkWidget *preview_widgets[MAXNPIECES];
+static GtkWidget *new_game_button;
 
 static gint window_width = 0, window_height = 0;
 static gboolean window_is_fullscreen = FALSE, window_is_maximized = FALSE;
@@ -409,8 +410,7 @@ start_game (void)
 {
   char string[20];
 
-  set_status_message (_
-                         ("Match five objects of the same type in a row to score!"));
+  set_status_message (_("Match five objects of the same type in a row to score!"));
   refresh_screen ();
   active = -1;
   target = -1;
@@ -418,6 +418,7 @@ start_game (void)
   g_snprintf (string, 19, "%d", score);
   gtk_label_set_text (GTK_LABEL (scorelabel), string);
   set_inmove (0);
+  gtk_widget_hide (new_game_button);
 }
 
 static void
@@ -471,7 +472,7 @@ show_scores (gint pos)
   static GtkWidget *dialog;
 
   if (dialog == NULL) {
-    dialog = games_scores_dialog_new (GTK_WINDOW (app), highscores, _("GNOME Five or More"));
+    dialog = games_scores_dialog_new (GTK_WINDOW (app), highscores, _("Five or More Scores"));
     games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
                                                   (dialog), _("_Board size:"));
   }
@@ -493,7 +494,7 @@ game_over (void)
   set_status_message (_("Game Over!"));
   pos = games_scores_add_plain_score (highscores, score);
   show_scores (pos);
-  return;
+  gtk_widget_show (new_game_button);
 }
 
 static int
@@ -647,7 +648,7 @@ cell_clicked (GtkWidget * widget, int fx, int fy)
         set_inmove (1);
       } else {
         /* Can't move there! */
-        set_status_message (_("You can't move there!"));
+        set_status_message (_("You can’t move there!"));
         reset_pathsearch ();
         target = -1;
       }
@@ -1181,7 +1182,7 @@ game_about_callback (GSimpleAction *action,
                          "version", VERSION,
                          "comments", _("GNOME port of the once-popular Color Lines game\n\nFive or More is a part of GNOME Games."),
                          "copyright",
-                         "Copyright \xc2\xa9 1997-2008 Free Software Foundation, Inc.",
+                         "Copyright © 1997–2008 Free Software Foundation, Inc.\n Copyright © 2013–2014 Michael Catanzaro",
                          "license-type", GTK_LICENSE_GPL_2_0,
                          "authors", authors,
                          "documenters", documenters,
@@ -1392,14 +1393,20 @@ game_props_callback (GSimpleAction *action,
     size_radio = GTK_WIDGET (gtk_builder_get_object (builder_preferences, "radiobutton_small"));
     g_signal_connect (size_radio, "clicked",
                       G_CALLBACK (size_callback), GINT_TO_POINTER (1));
+    if (game_size == SMALL)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (size_radio), TRUE);
 
     size_radio = GTK_WIDGET (gtk_builder_get_object (builder_preferences, "radiobutton_medium"));
     g_signal_connect (size_radio, "clicked",
                       G_CALLBACK (size_callback), GINT_TO_POINTER (2));
+    if (game_size == MEDIUM)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (size_radio), TRUE);
 
     size_radio = GTK_WIDGET (gtk_builder_get_object (builder_preferences, "radiobutton_large"));
     g_signal_connect (size_radio, "clicked",
                       G_CALLBACK (size_callback), GINT_TO_POINTER (3));
+    if (game_size == LARGE)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (size_radio), TRUE);
 
     fast_moves_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder_preferences, "checkbutton_fast_moves"));
     if (move_timeout == 10) {
@@ -1518,7 +1525,7 @@ static void
 startup_cb (GApplication *application)
 {
   gchar *ui_path;
-  GtkWidget *vbox;
+  GtkWidget *hbox;
   GtkWidget *preview_hbox;
   guint i;
   GError *error = NULL;
@@ -1581,6 +1588,7 @@ startup_cb (GApplication *application)
     gtk_window_fullscreen (GTK_WINDOW (app));
   if (g_settings_get_boolean (settings, "window-is-maximized"))
     gtk_window_maximize (GTK_WINDOW (app));
+  gtk_container_set_border_width (GTK_CONTAINER (app), 20);
   gtk_application_add_window (GTK_APPLICATION (application), GTK_WINDOW (app));
 
   headerbar = GTK_WIDGET (gtk_builder_get_object (builder, "headerbar"));
@@ -1600,7 +1608,7 @@ startup_cb (GApplication *application)
 
   scorelabel = GTK_WIDGET (gtk_builder_get_object (builder, "scorelabel"));
 
-  vbox = GTK_WIDGET (gtk_builder_get_object (builder, "vbox"));
+  hbox = GTK_WIDGET (gtk_builder_get_object (builder, "hbox"));
   draw_area = gtk_drawing_area_new ();
   g_signal_connect (draw_area, "button-press-event",
                     G_CALLBACK (button_press_event), NULL);
@@ -1610,10 +1618,11 @@ startup_cb (GApplication *application)
                     G_CALLBACK (configure_event_callback), NULL);
   g_signal_connect (draw_area, "draw",
                     G_CALLBACK (field_draw_callback), NULL);
+  gtk_widget_set_size_request (draw_area, 400, 400);
   gridframe = games_grid_frame_new (hfieldsize, vfieldsize);
   games_grid_frame_set_padding (GAMES_GRID_FRAME (gridframe), 1, 1);
   gtk_container_add (GTK_CONTAINER (gridframe), draw_area);
-  gtk_box_pack_start (GTK_BOX (vbox), gridframe, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), gridframe, TRUE, FALSE, 0);
 
   gtk_widget_set_events (draw_area,
                          gtk_widget_get_events (draw_area) |
@@ -1622,6 +1631,8 @@ startup_cb (GApplication *application)
   gtk_widget_set_can_focus (draw_area, TRUE);
   gtk_widget_grab_focus (draw_area);
 
+  new_game_button = GTK_WIDGET (gtk_builder_get_object (builder, "new_game_button"));
+
   load_properties ();
 
   gtk_builder_connect_signals (builder, NULL);
